# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from bootspeed.models import (
    Image,
    Machine,
    ImageResult,
    ImageMachineAgg,
    ImageResultLog,
    JobImage,
    ImageBuild,
)

from django.contrib import admin


class ImageAdmin(admin.ModelAdmin):
    list_display = (
        'build_number',
        'release',
        'variant',
        'arch',
        'image_type',
        'publish',
    )
    list_filter = ['publish', 'arch', 'release', 'variant', 'image_type']
    search_fields = ['build_number']


class MachineAdmin(admin.ModelAdmin):
    list_display = ('name', 'publish')
    list_filter = ['name', 'publish']


class ImageResultAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'machine',
        'publish',
    )
    list_filter = ['publish', 'image__release', 'image__arch', 'machine']
    search_fields = [
        'image__build_number',
        'image__arch',
        'image__release',
    ]
    date_hierarchy = 'ran_at'
    ordering = ['-image__build_number']


class ImageMachineAggAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'machine',
        'publish',
    )
    list_filter = ['publish', 'image__release', 'image__arch', 'machine']
    search_fields = [
        'image__build_number',
        'image__arch',
        'image__release',
    ]
    ordering = ['-image__build_number']


class ImageResultLogAdmin(admin.ModelAdmin):
    list_display = ('display_name', 'image_result', 'publish')
    list_filter = ['publish', 'image_result__image']
    ordering = ['-image_result']


class JobImageAdmin(admin.ModelAdmin):
    list_display = ('build_number', 'release', 'arch', 'variant', 'publish')
    list_filter = ['publish', 'release', 'arch', 'variant']
    ordering = ['-build_number']


class ImageBuildAdmin(admin.ModelAdmin):
    list_display = ('build', 'job_image', 'publish')
    list_filter = [
        'publish',
        'job_image__release',
        'job_image__arch',
        'job_image__variant',
    ]
    ordering = ['-build']


admin.site.register(Image, ImageAdmin)
admin.site.register(Machine, MachineAdmin)
admin.site.register(ImageResult, ImageResultAdmin)
admin.site.register(ImageMachineAgg, ImageMachineAggAdmin)
admin.site.register(ImageResultLog, ImageResultLogAdmin)
admin.site.register(JobImage, JobImageAdmin)
admin.site.register(ImageBuild, ImageBuildAdmin)
