# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from common.models import (
    Bug,
    JenkinsJob,
    JenkinsBuild,
    Artifact,
    UserProfile,
)

from django.contrib import admin


class BugAdmin(admin.ModelAdmin):
    list_display = ('bug_no', 'status', 'importance', 'project', 'publish')
    list_filter = ['publish', 'status', 'importance', 'project']
    search_fields = ['bug_no', 'assignee']


class JenkinsJobAdmin(admin.ModelAdmin):
    list_display = ('name', 'url', 'bug_count', 'publish')
    list_filter = ['publish', ]
    search_fields = ['name', 'url']


class JenkinsBuildAdmin(admin.ModelAdmin):
    list_display = (
        'build_number',
        'job',
        'failed',
        'ran_at',
        'publish',
    )

    list_filter = [
        'publish',
        'failed',
        'job',
    ]
    date_hierarchy = 'ran_at'


class ArtifactAdmin(admin.ModelAdmin):
    list_display = ('name', 'jenkins_build', 'publish')
    search_fields = ['name', 'jenkins_build']


class UserProfileAdmin(admin.ModelAdmin):
    list_display = ('user', 'use_private_url')
    search_fields = ['user', ]

admin.site.register(Bug, BugAdmin)
admin.site.register(JenkinsJob, JenkinsJobAdmin)
admin.site.register(JenkinsBuild, JenkinsBuildAdmin)
admin.site.register(Artifact, ArtifactAdmin)
admin.site.register(UserProfile, UserProfileAdmin)
