# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

from django.core.management.base import BaseCommand

from common.management import process_class_list
from common.utils import get_class_map

MAX_DELETE = 100000


class Command(BaseCommand):
    args = "[Class name] [Class name]..."
    help = "List items in the dashboard tables.  Useful for degugging."

    def handle(self, *args, **options):

        klass_map = get_class_map()

        klasses = []
        for ks in klass_map.values():
            for klass in ks:
                klasses.append(klass)

        verbosity = int(options.get('verbosity'))

        klass_list = process_class_list(args)

        if verbosity > 1:
            for klass in klasses:
                if klass_list and klass.__name__ not in klass_list:
                    continue

                print(klass.__name__)

        for klass in klasses:
            if klass_list and klass.__name__ not in klass_list:
                continue

            if verbosity > 1:
                print(klass.__name__)

            if klass.objects.count() > MAX_DELETE:
                for item in klass.objects.all().iterator():
                    item.delete()

            klass.objects.all().delete()
