# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import logging

from datetime import datetime
from optparse import make_option

from launchpadlib.launchpad import Launchpad

from django.core.management.base import BaseCommand

from qa_dashboard.settings import LAUNCHPADLIB_CACHE

from common.models import Bug


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option(
            '-b', '--bug',
            type='int',
            dest='pull_bug',
            help='Pull the data for the bug number provided',
        ),
    )

    help = 'Pull bug data from Launchpad'

    def handle(self, *args, **options):
        start_time = datetime.now()
        pull_bug = options.get('pull_bug')
        verbosity = int(options.get('verbosity'))
        if verbosity > 1:
            logging.basicConfig(level=logging.DEBUG)

        if not os.path.exists(LAUNCHPADLIB_CACHE):
            os.makedirs(LAUNCHPADLIB_CACHE, 0700)
        launchpad = Launchpad.login_anonymously(
            'QA Dashboard',
            'production',
            LAUNCHPADLIB_CACHE,
        )

        if pull_bug:
            try:
                Bug.objects.get(bug_no=pull_bug)
            except:
                logging.error("%s is not a valid dashboard bug", pull_bug)
                return None
            bugs = [pull_bug]
        else:
            bugs = Bug.objects.all()

        for bug in bugs:
            if not pull_bug:
                bug = bug.bug_no
            try:
                bug_lp = launchpad.bugs[bug]
                if bug_lp.duplicate_of:
                    bug_lp = launchpad.bugs[bug_lp.duplicate_of.id]
            except KeyError:
                logging.info("Unable to load bug: %s" % bug)
                continue

            if len(bug_lp.bug_tasks) == 1:
                bug_task = bug_lp.bug_tasks[0]
            else:
                for task in bug_lp.bug_tasks:
                    if 'ubuntu/+source' in task.self_link or \
                       'ubuntu/+bug' in task.self_link:

                        bug_task = task
                        break
                    else:
                        bug_task = bug_lp.bug_tasks[0]

            if bug_task.assignee:
                try:
                    bug_assignee = unicode(bug_task.assignee.display_name)
                except:
                    try:
                        bug_assignee = unicode(bug_task.assignee.name)
                    except:
                        bug_assignee = unicode("Unknown")
            else:
                bug_assignee = None

            update_bug = Bug.objects.get(bug_no=bug)
            update_bug.project = unicode(bug_task.bug_target_display_name)
            update_bug.title = unicode(bug_lp.title)
            update_bug.status = unicode(bug_task.status)
            update_bug.importance = bug_task.importance
            update_bug.assignee = bug_assignee
            update_bug.save()
            logging.info(
                "Updating bug #%s with:\n"
                "title: %s\n"
                "status: %s\n"
                "importance: %s\n"
                "assignee: %s\n",
                bug,
                update_bug.title,
                update_bug.status,
                update_bug.importance,
                update_bug.assignee,
            )
        logging.debug("time: {}".format(datetime.now() - start_time))
