#!/usr/bin/python
# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import subprocess

from bzrlib.missing import find_unmerged
from bzrlib.branch import Branch

from django.core.management.base import NoArgsCommand

from qa_dashboard import settings

from plugins import EXTERNAL_APPS


class Command(NoArgsCommand):
    help = "Add external projects to the QA Dashboard for development"

    def handle_noargs(self, **options):
        path = settings.PROJECT_PATH
        reload = False
        for bzrapp in EXTERNAL_APPS:
            app = os.path.basename(bzrapp)

            destination = os.path.join(path, '..', app)
            if os.path.isdir(destination):
                local = Branch.open(destination)
                parent = Branch.get_parent(local)
                parent = Branch.open(parent)
                missing = find_unmerged(local, parent, restrict='remote')
                if missing[1]:
                    print(" * Updating %s" % app)
                    subprocess.check_call(["bzr", "pull"], cwd=destination)
                    reload = True
                    print(" * %s updated." % app)
            else:
                if settings.CONFIGURATION != 'production':
                    print(" * Adding %s" % app)
                    subprocess.check_call(
                        [
                            "bzr",
                            "branch",
                            "-q",
                            bzrapp,
                            app,
                        ],
                    )
                    print(" * %s added." % app)
        if reload:
            subprocess.check_call(["python", "manage.py", "syncdb"])
            subprocess.check_call(["python", "manage.py", "migrate"])
            subprocess.check_call(
                [
                    "python",
                    "manage.py",
                    "collectstatic",
                    "--noinput",
                ],
            )
            subprocess.check_call(
                [
                    "sudo",
                    "service",
                    "apache2",
                    "graceful",
                ],
            )
