# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import json

from django.test import TestCase

DB_SETTINGS_DB = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': 'db_qa_dashboard',
        'USER': 'qa_user',
        'PASSWORD': 'qa_pass',
        'HOST': 'localhost',
        'PORT': '',
    }
}

AMQP_SETTINGS = {
    'publishers': [
        {
            'type': 'amqp',
            'host': 'amqp_host',
            'user': 'user',
            'password': 'password',
            'vhost': 'amqp_vhost',
            'exchange_name': 'armani',
            'routing_key': 'abc-123',
            },
        {
            'type': 'datedir',
            'error_dir': 'oops',
            'new_only': True,
        },
    ],
}


class TestSettings(TestCase):

    def test_db_settings_database(self):
        if os.path.exists("db_settings.py"):
            os.rename("db_settings.py", "db_settings.py.test")
        with open("db_settings.py", "w") as fp:
            fp.write("DATABASES = {}".format(str(DB_SETTINGS_DB)))
        import db_settings
        import qa_dashboard.settings
        reload(db_settings)
        reload(qa_dashboard.settings)
        self.assertEqual(qa_dashboard.settings.DATABASES, DB_SETTINGS_DB)
        os.remove('db_settings.py')
        os.remove('db_settings.pyc')
        if os.path.exists("db_settings.py.test"):
            os.rename("db_settings.py.test", "db_settings.py")

    def test_amqp_settings(self):
        if os.path.exists("amqp_settings.py"):
            os.rename("amqp_settings.py", "amqp_settings.py.test")
        with open("amqp_settings.py", "w") as fp:
            fp.write("oops_config = {}".format(str(AMQP_SETTINGS)))
        import amqp_settings
        import qa_dashboard.settings
        reload(amqp_settings)
        reload(qa_dashboard.settings)
        self.assertEqual(qa_dashboard.settings.oops_config, AMQP_SETTINGS)
        os.remove('amqp_settings.py')
        os.remove('amqp_settings.pyc')
        if os.path.exists("amqp_settings.py.test"):
            os.rename("amqp_settings.py.test", "amqp_settings.py")
