# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.decorators import login_required
from django.views.decorators.http import require_GET
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.core.exceptions import PermissionDenied
from django.contrib.auth import logout
from django.http import HttpResponseRedirect

from common.plugin_helper import ExtensionManager
from common.bread_crumbs import BreadCrumb, BreadCrumbTrail
from common.models import UserProfile
from common.forms import EditProfileForm


@BreadCrumb("CI Dashboard")
@require_GET
def index(request):
    ext_man = ExtensionManager()
    kpi_html = ext_man.kpi_render()
    data = {
        'kpi_html': kpi_html,
        'bread_crumb_trail': BreadCrumbTrail.leading_to(index),
    }

    return render_to_response('kpi.html', data, RequestContext(request))


def cause_oops(request):
    if request.user.is_staff:
        raise AssertionError("Manually generated OOPS")
    else:
        raise PermissionDenied


def logout_view(request):
    logout(request)
    return HttpResponseRedirect('/')


@login_required
def edit_profile(request):
    form_title = 'Edit profile'
    try:
        profile = UserProfile.objects.get(user=request.user)
    except UserProfile.DoesNotExist:
        profile = UserProfile(user=request.user)

    if request.method == 'POST':
        form = EditProfileForm(data=request.POST, instance=profile)
        if form.is_valid():
            form.save()
            return HttpResponseRedirect('/')
    else:
        form = EditProfileForm(instance=profile)

    context = {
        'form': form,
        'form_title': form_title,
    }
    return render_to_response(
        'form.html',
        context,
        RequestContext(request)
    )
