# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django_tables2 as tables
from django_tables2.utils import Accessor as A

from eventstat.models import (
    EventstatDetail,
    EventstatMetric,
)


class DetailTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = EventstatDetail
        fields = (
            'total',
        )

    total = tables.TemplateColumn(
        "{{ record.total|floatformat }}",
        verbose_name="Wakeups",
        attrs={'td': {'class': 'num'}},
    )


class MetricTable(tables.Table):
    class Meta:
        attrs = {'class': 'basic wide'}
        model = EventstatMetric
        fields = (
            'average',
            'minimum',
            'maximum',
            'stddev',
            'pct_stddev',
        )

    average = tables.TemplateColumn(
        "{{ record.average|floatformat }}",
        verbose_name="Average",
        attrs={'td': {'class': 'num'}},
    )
    minimum = tables.TemplateColumn(
        "{{ record.minimum|floatformat }}",
        verbose_name="Minimum",
        attrs={'td': {'class': 'num'}},
    )
    maximum = tables.TemplateColumn(
        "{{ record.maximum|floatformat }}",
        verbose_name="Maximum",
        attrs={'td': {'class': 'num'}},
    )
    stddev = tables.TemplateColumn(
        "{{ record.stddev|floatformat }}",
        verbose_name="Standard Deviation",
        attrs={'td': {'class': 'num'}},
    )
    pct_stddev = tables.TemplateColumn(
        "{{ record.pct_stddev|floatformat }}",
        verbose_name="% Standard Deviation",
        attrs={'td': {'class': 'num'}},
    )


class TaskInstallTable(MetricTable):

    class Meta(MetricTable.Meta):
        fields = (
            "task",
        )
        order_by = ("-change", "task")

    task = tables.LinkColumn(
        "eventstat.views.image_task_overview",
        kwargs={
            "image_id": A("image_id"),
            "machine_id":  A("machine_id"),
            "task": A("task"),
        },
    )
    movement = tables.TemplateColumn(
        '<div class="movement-{{ record.movement }}">&nbsp;</div>',
        verbose_name='Direction',
    )
    change = tables.TemplateColumn(
        '{{ record.change|floatformat }}',
        attrs={'td': {'class': 'num'}},
    )


class TaskUpgradeTable(MetricTable):

    class Meta(MetricTable.Meta):
        fields = (
            "task",
        )
        order_by = ("-change", "task")

    task = tables.LinkColumn(
        "eventstat.views.upgrade_task_overview",
        kwargs={
            "upgrade_id": A("upgrade_id"),
            "machine_id":  A("machine_id"),
            "task": A("task"),
        },
    )
    movement = tables.TemplateColumn(
        '<div class="movement-{{ record.movement }}">&nbsp;</div>',
        verbose_name='Direction',
    )
    change = tables.TemplateColumn(
        '{{ record.change|floatformat }}',
        attrs={'td': {'class': 'num'}},
    )


class MachineUpgradeDetailsTable(MetricTable):

    class Meta(MetricTable.Meta):
        order_by = ("-upgrade_date",)
        fields = (
            'upgrade_date',
        )

    upgrade_date = tables.LinkColumn(
        'eventstat.views.upgrade_details',
        accessor="upgrade_date",
        kwargs={
            'task_type': 'all',
            'upgrade_id': A('upgrade_id'),
            'machine_id': A('machine'),
        },
        verbose_name="Upgrade Date",
    )


class MachineInstallDetailsTable(MetricTable):

    class Meta(MetricTable.Meta):
        order_by = ("-build_number",)
        fields = (
            "build_number",
        )

    build_number = tables.LinkColumn(
        'eventstat.views.image_details',
        accessor="build_number",
        kwargs={
            'task_type': 'all',
            'image_id': A('image_id'),
            'machine_id': A('machine'),
        },
        verbose_name="Build Number",
    )


class InstallTaskOverviewTable(MetricTable):

    class Meta(MetricTable.Meta):
        fields = (
            'task',
        )
        order_by = ('-average')

    task = tables.LinkColumn(
        'eventstat.views.task_overview',
        kwargs={
            'machine_id': A('machine_id'),
            'arch': A('image__arch'),
            'method': "install",
            'task': A('task'),
        }
    )


class UpgradeTaskOverviewTable(MetricTable):

    class Meta(MetricTable.Meta):
        fields = (
            'task',
        )
        order_by = ('-average')

    task = tables.LinkColumn(
        'eventstat.views.task_overview',
        kwargs={
            'machine_id': A('machine_id'),
            'arch': A('upgrade__arch'),
            'method': "upgrade",
            'task': A('task'),
        }
    )
