# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models

from eventstat.models import (
    EventstatImage,
    EventstatMachine,
    EventstatMetric,
    EventstatResult,
    EventstatUpgrade,
    EventstatDetail,
)


def get_metrics(arch=None, image=None, upgrade=None):

    metrics = EventstatMetric.objects.filter(publish=True)

    if arch is not None:
        metrics = metrics.filter(arch=arch)

    if image is not None:
        metrics = metrics.filter(image=image)

    if upgrade is not None:
        metrics = metrics.filter(upgrade=upgrade)

    return metrics


def get_machine_metrics(machine, name, method):

    if name is None:
        name = "total"

    metrics = EventstatMetric.objects.filter(
        publish=True,
        machine=machine,
        name=name,
    )

    if method == "image":
        metrics = metrics.filter(
            image__isnull=False,
        )
    else:
        metrics = metrics.filter(
            upgrade__isnull=False,
        )

    return metrics


def get_images(arch=None):

    images = EventstatImage.objects.filter(publish=True)

    if arch is not None:
        images = images.filter(arch=arch)

    return images


def get_upgrades(arch=None):

    upgrades = EventstatUpgrade.objects.filter(publish=True)

    if arch is not None:
        upgrades = upgrades.filter(arch=arch)

    return upgrades


def get_arches():

    results = EventstatResult.objects.filter(publish=True).values(
        'image__arch',
        'upgrade__arch',
    )

    image_results = set(filter(None, [x['image__arch'] for x in results]))
    upgrade_results = set(filter(None, [x['upgrade__arch'] for x in results]))

    return list(image_results.union(upgrade_results))


def get_machines(arch=None):

    metrics = EventstatMetric.objects.filter(
        publish=True,
    ).values(
        'machine',
        'image__arch',
        'upgrade__arch',
    )

    if arch is not None:
        metrics = metrics.filter(
            models.Q(image__arch=arch) | models.Q(upgrade__arch=arch),
        )

    metrics = metrics.distinct().values('machine')

    machine_ids = [x['machine'] for x in metrics]

    machines = EventstatMachine.objects.exclude(
        publish=False,
    ).filter(
        id__in=machine_ids,
    )

    return machines


def previous(machine, task, image=None, upgrade=None):
    """ The previous process data. """
    prev = EventstatDetail.objects.filter(
        machine=machine,
        task=task,
    ).exclude(
        publish=False,
    )

    if upgrade is not None:
        prev = prev.filter(
            upgrade__date__lt=upgrade,
        ).values('upgrade__date').annotate(
            average=models.Avg('total'),
        )
        prev = prev.exclude(upgrade=None).order_by('-upgrade__date')
    else:
        prev = prev.filter(
            image__build_number__lt=image,
        ).values('image__build_number').annotate(
            average=models.Avg('total'),
        )
        prev = prev.exclude(image=None).order_by('-image__build_number')
    if prev.count() == 0:
        return None
    prev = prev[0]

    prev = prev['average']
    return prev
