# QA Dashboard

# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json

from django.views.decorators.http import require_GET
from django.db.models import Min, Max, Avg, StdDev

from common.utils import (
    JSONResponse,
)

from idle_power.config import get_control

from idle_power.models import (
    IdlePowerImage,
    IdlePowerBuild,
)

MAX_RESULTS = 180


@require_GET
def machine_details(request, testcase, machine_id, arch):
    qs = IdlePowerBuild.objects.filter(
        machine__id=machine_id,
        image__arch=arch,
        image__image_type='daily',
    )
    test = qs.filter(image__idlepowerdetail__testcase=testcase).annotate(
        bottom=Min('image__idlepowerdetail__energy_used'),
        minimum=Min('image__idlepowerdetail__energy_used'),
        average=Avg('image__idlepowerdetail__energy_used'),
        maximum=Max('image__idlepowerdetail__energy_used'),
        stddev=StdDev('image__idlepowerdetail__energy_used'),
    ).order_by('image__build_number')[:MAX_RESULTS]

    control_test = get_control(testcase)
    control_results = qs.filter(
        image__idlepowerdetail__testcase=control_test,
    ).annotate(
        control_average=Avg('image__idlepowerdetail__energy_used'),
    ).order_by('image__build_number')[:MAX_RESULTS]

    control = dict(
        (x.image.build_number, x.control_average) for x in control_results
    )

    last_releases = IdlePowerImage.objects.filter(
        idlepowerdetail__testcase=testcase,
        idlepowerdetail__machine=machine_id,
        arch=arch,
        image_type='release',
    ).order_by('-build_number').annotate(
        average=Avg('idlepowerdetail__energy_used')
    )[:1]

    if last_releases.count() > 0:
        last_release_avg = last_releases[0].average

        last_release_name = last_releases[0].release
    else:
        last_release_avg = 0.0
        last_release_name = 'Unknown'

    bundle = {
        'last_release_avg': last_release_avg,
        'last_release_name': last_release_name,
        'control': control_test,
    }
    image_data = []
    for t in test:
        image_info = dict(
            bottom=t.minimum,
            min=t.minimum,
            max=t.maximum,
            avg=t.average,
            stddev=t.stddev,
            control_avg=control[t.image.build_number],
            build_number=t.image.build_number,
        )
        image_data.append(image_info)

    bundle['count'] = len(image_data)
    bundle['image_data'] = image_data
    data = json.dumps(bundle)
    return JSONResponse(data)
