# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models

from common.models import (
    DashboardBaseModel,
    JenkinsBuild,
)

from performance.models import (
    ImageBase,
    MachineBase,
)


class IdlePowerImage(ImageBase):
    """ Idle Power Image model. """

    class Meta:
        db_table = "idle_power_images"


class IdlePowerMachine(MachineBase):
    """ Idle Power Machine model. """

    class Meta:
        db_table = "idle_power_machines"


class IdlePowerLog(DashboardBaseModel):
    """ Idle Power logs for a build. """

    class Meta:
        db_table = "idle_power_logs"

    path = models.CharField(max_length=4096)
    name = models.CharField(max_length=4096)

    def __unicode__(self):
        return "{}".format(self.name)


class IdlePowerDetail(DashboardBaseModel):
    """ Idle Power raw data. """

    class Meta:
        db_table = "idle_power_details"

    image = models.ForeignKey(IdlePowerImage, null=True)
    machine = models.ForeignKey(IdlePowerMachine)
    testcase = models.CharField(max_length=4096)
    calculated_energy = models.PositiveIntegerField()
    charge_start = models.PositiveIntegerField()
    charge_used = models.PositiveIntegerField()
    energy_start = models.PositiveIntegerField()
    energy_used = models.PositiveIntegerField()
    duration = models.PositiveIntegerField()
    ran_at = models.DateTimeField("date run")
    jenkins_url = models.URLField(max_length=4096)

    def __unicode__(self):
        return "{}".format(self.testcase)


class IdlePowerBuild(DashboardBaseModel):
    """ Jenkins Build image. """

    class Meta:
        db_table = "idle_power_builds"

    image = models.ForeignKey(IdlePowerImage, null=True)
    machine = models.ForeignKey(IdlePowerMachine)
    build = models.ForeignKey(JenkinsBuild)
