# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django_tables2 as tables
from django_tables2.utils import Accessor as A


class MachineTable(tables.Table):
    build_number = tables.LinkColumn(
        'idle_power_machine_raw_data',
        accessor='image__build_number',
        kwargs={
            'machine_id': A('machine__id'),
            'arch': A('image__arch'),
            'build_number': A('image__build_number'),
        },
        verbose_name="Build Number",
    )
    testcase = tables.Column(verbose_name="Test Case")
    energy_avg = tables.TemplateColumn(
        '{{ record.energy_avg|floatformat:2 }}',
        verbose_name="Average Energy used (mW)",
        attrs={'td': {'class': 'num'}},
    )
    energy_stddev = tables.TemplateColumn(
        '{{ record.energy_stddev|floatformat:2 }}',
        verbose_name="Standard Deviation",
        attrs={'td': {'class': 'num'}},
    )
    energy_percent_stddev = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.energy_stddev|percent:record.energy_avg|floatformat:2 }}',
        verbose_name="% Standard Deviation",
        attrs={'td': {'class': 'num'}},
    )

    class Meta:
        attrs = {'class': 'basic'}


class DataTable(tables.Table):
    testcase = tables.Column(verbose_name="Test Case")
    energy_start = tables.Column(
        verbose_name="Energy Start (mW)",
        attrs={'td': {'class': 'num'}},
    )
    energy_used = tables.Column(
        verbose_name="Energy used (mW)",
        attrs={'td': {'class': 'num'}},
    )
    calculated_energy = tables.Column(
        verbose_name="Calculated Energy (mW)",
        attrs={'td': {'class': 'num'}},
    )
    charge_start = tables.Column(
        verbose_name="Charge Start (mA)",
        attrs={'td': {'class': 'num'}},
    )
    charge_used = tables.Column(
        verbose_name="Charge Used (mA)",
        attrs={'td': {'class': 'num'}},
    )

    class Meta:
        attrs = {'class': 'basic'}
        order_by = ('testcase',)
