# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.test import TestCase
from django.core.urlresolvers import reverse
from django.test.client import Client

from model_mommy import mommy


class TestIdlePower(TestCase):
    """ Tests for power models. """

    c = Client()

    def setUp(self):
        """ Setup commonly used objects. """

        mommy.make_recipe('idle_power.job')
        mommy.make_recipe('idle_power.jenkins_build')
        self.image3861 = mommy.make_recipe('idle_power.image386')
        self.image641 = mommy.make_recipe('idle_power.image64')
        self.image_release386 = mommy.make_recipe(
            'idle_power.image386',
            image_type='release',
        )
        self.image_release64 = mommy.make_recipe(
            'idle_power.image64',
            image_type='release',
        )
        self.machine1 = mommy.make_recipe('idle_power.machine')
        self.machine2 = mommy.make_recipe('idle_power.machine')
        self.build641 = mommy.make_recipe(
            'idle_power.build',
            machine=self.machine2,
            image=self.image641,
        )
        self.detail3861 = mommy.make_recipe(
            'idle_power.detail',
            machine=self.machine1,
            image=self.image3861,
            _quantity=10,
        )
        self.detail641 = mommy.make_recipe(
            'idle_power.detail',
            machine=self.machine2,
            image=self.image641,
            _quantity=10,
        )
        self.detail_release386 = mommy.make_recipe(
            'idle_power.detail',
            machine=self.machine1,
            image=self.image_release386,
            _quantity=10,
        )
        self.detail_release64 = mommy.make_recipe(
            'idle_power.detail',
            machine=self.machine2,
            image=self.image_release64,
            _quantity=10,
        )
        self.burn_detail64 = mommy.make_recipe(
            'idle_power.burn_detail',
            machine=self.machine2,
            image=self.image641,
            _quantity=10,
        )

    def test_detail(self):
        """
        Testing that one of the deatils has the correct
        machine and image assigned
        """
        self.assertEqual(self.detail3861[0].image, self.image3861)
        self.assertEqual(self.detail3861[0].machine, self.machine1)

    def test_no_arch_overview(self):
        response = self.c.get(reverse('idle_power_arch', ))
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(
            response,
            'idle_power/arch_overview.html',
        )

    def test_arch_overview(self):
        rev_args = [self.image3861.arch, ]
        response = self.c.get(
            reverse(
                'idle_power_arch_overview',
                args=rev_args,
            )
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'idle_power/arch_overview.html')

    def test_machine_table(self):
        rev_args = [self.machine1.id, self.image3861.arch]
        response = self.c.get(
            reverse(
                'idle_power_machine_detail',
                args=rev_args,
            )
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'idle_power/machine_table.html')

    def test_machine_raw_data(self):
        rev_args = [
            self.machine1.id,
            self.image3861.arch,
            self.image3861.build_number,
        ]
        response = self.c.get(
            reverse(
                'idle_power_machine_raw_data',
                args=rev_args,
            )
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'idle_power/machine_raw_data.html')

    def test_api(self):
        rev_args = [
            self.machine2.id,
            self.image641.arch,
            self.detail641[0].testcase,
        ]
        response = self.c.get(
            reverse(
                'idle_power_api_machine_details',
                args=rev_args,
            )
        )
        self.assertEqual(response.status_code, 200)
        self.assertContains(response, self.detail641[7].image.build_number)
