# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json

from django.views.decorators.http import require_GET

from common.utils import (
    JSONResponse,
    MySerializer,
)

from memevent.models import (
    MemoryEventDetail,
    MemoryEventImage,
    MemoryEventMachine,
)


@require_GET
def event_overview(request, machine, event):

    details = MemoryEventDetail.objects.filter(
        publish=True,
        event=event,
        machine__name=machine,
    )

    chart_data = {}
    for detail in details:
        chart_data.setdefault(detail.command, []).append(dict(
            build_number=detail.image.build_number,
            event=detail.event,
            run=detail.run,
            ran_at=detail.ran_at.strftime("%c"),
            pss=float(detail.pss) / 1024,  # in MB
        ))

    ret_data = []
    for proc in sorted(chart_data.keys(), reverse=True):
        values = chart_data[proc]
        index = 0
        for value in values:
            value['index'] = index
            index += 1

        ret_data.append(dict(
            key=proc,
            values=sorted(
                values,
                key=lambda item: item['index'],
            ),
        ))

    data = json.dumps(ret_data)

    return JSONResponse(data)


@require_GET
def detail_overview(request, image_id, machine):

    details = MemoryEventDetail.objects.filter(
        publish=True,
        image__id=image_id,
        machine__name=machine,
    )

    chart_data = {}
    for detail in details:
        chart_data.setdefault(detail.command, []).append(dict(
            x=detail.event,
            y=float(detail.pss) / 1024,  # in MB
            index=detail.event_index,
        ))

    ret_data = []
    for proc in sorted(chart_data.keys(), reverse=True):
        values = chart_data[proc]
        ret_data.append(dict(
            key=proc,
            values=sorted(values, key=lambda item: item['index']),
        ))

    data = json.dumps(ret_data)

    return JSONResponse(data)


@require_GET
def machine_overview(request):

    details = MemoryEventMachine.objects.filter(
        publish=True,
    )

    serializer = MySerializer()
    data = serializer.serialize(details)

    return JSONResponse(data)


@require_GET
def image_overview(request):

    details = MemoryEventImage.objects.filter(
        publish=True,
    )

    serializer = MySerializer()
    data = serializer.serialize(details)

    return JSONResponse(data)
