# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.


from django.db import models

from common.models import (
    DashboardBaseModel,
    JenkinsBuild,
)

from performance.models import (
    ImageBase,
    MachineBase,
)


class MemoryEventImage(ImageBase):
    """ Memory Event Image model. """

    class Meta:
        db_table = "memevent_images"


class MemoryEventMachine(MachineBase):
    """ Memory Event Machine model. """

    class Meta:
        db_table = "memevent_machines"


class MemoryEventDetail(DashboardBaseModel):
    """ Memory Event Detail model. """

    class Meta:
        db_table = "memevent_details"

    image = models.ForeignKey(MemoryEventImage)
    machine = models.ForeignKey(MemoryEventMachine)
    command = models.CharField(max_length=4096)
    pid = models.IntegerField()
    pss = models.PositiveIntegerField()
    rss = models.PositiveIntegerField()
    uss = models.PositiveIntegerField()
    swap = models.PositiveIntegerField()
    pss_threshold = models.PositiveIntegerField(default=128 * 1024)  # KB
    user = models.CharField(max_length=4096)
    ran_at = models.DateTimeField()
    event = models.CharField(max_length=4096)
    event_index = models.PositiveIntegerField()
    run = models.PositiveIntegerField()
    jenkins_build = models.ForeignKey(JenkinsBuild)


class MemoryEventThreshold(DashboardBaseModel):
    """ Memory Event Threshold model. """

    class Meta:
        db_table = "memevent_thresholds"

    image = models.ForeignKey(MemoryEventImage)
    machine = models.ForeignKey(MemoryEventMachine)
    threshold = models.FloatField()
