# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.


import datetime
import logging
import os
import random
import sys

sys.path.append(os.path.join(os.path.dirname(__file__), '..', '..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'qa_dashboard.settings'

logging.basicConfig(level=logging.INFO)

from memevent.models import (
    MemoryEventDetail,
    MemoryEventImage,
    MemoryEventMachine,
)


def add_machines(count=3):

    machines = []

    for i in range(count):
        machines.append(
            MemoryEventMachine.objects.create(
                name='memevent-test-{}'.format(i),
            )
        )

    return machines


def add_images(count=1):

    images = []

    for i in range(count):
        images.append(
            MemoryEventImage.objects.create(
                arch='amd64',
                variant='desktop',
                release='raring',
                build_number='{}'.format(i),
                md5='fake{}'.format(i),
            )
        )
        images.append(
            MemoryEventImage.objects.create(
                arch='i386',
                variant='desktop',
                release='raring',
                build_number='{}'.format(i),
                md5='fake1{}'.format(i),
            )
        )

    return images


def add_details(machine, image, count=3):

    details = []

    for j in range(count):
        date = datetime.datetime.now()

        for i in range(count):
            details.append(
                MemoryEventDetail.objects.create(
                    image=image,
                    machine=machine,
                    command="detail_name",
                    user="root",
                    pid=j * count + i,
                    pss=random.randint(0, 100),
                    rss=random.randint(0, 100),
                    uss=random.randint(0, 100),
                    swap=random.randint(0, 100),
                    ran_at=date,
                )
            )


def cleanup():

    for klass in [
        MemoryEventDetail,
        MemoryEventMachine,
        MemoryEventImage,
    ]:
        logging.debug("klass: {}".format(klass))
        klass.objects.all().delete()


def list_stuff():

    for klass in [MemoryEventImage, MemoryEventMachine, MemoryEventDetail]:
        for item in klass.objects.all():
            logging.debug(item)

if __name__ == "__main__":
    cleanup()
    machines = add_machines(count=3)
    images = add_images(count=10)

    for image in images:
        for machine in machines:
            add_details(machine, image)
