# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django_tables2 as tables

from memevent.models import (
    MemoryEventDetail,
    MemoryEventImage,
)


class DetailTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventDetail
        fields = (
            'command',
            'pss',
            'uss',
            'rss',
            'swap',
            'user',
        )

    command = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '<a href="{{ record.jenkins_build.url }}">'
        '{{ record.command }}</a>',
        attrs={'td': {'class': 'shorten_command'}}
    )

    pss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pss|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )

    uss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.uss|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )

    rss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.rss|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )

    swap = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.swap|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )


class EventDetailTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventDetail
        fields = (
            'run',
            'command',
            'pss',
            'over_pss_threshold',
            'uss',
            'rss',
            'swap',
            'user',
        )
        order_by = ('run',)

    command = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '<a href="{{ record.jenkins_build__job__url }}'
        '{{ record.jenkins_build__build_number }}">'
        '{{ record.command }}</a>',
        attrs={'td': {'class': 'shorten_command'}}
    )

    pss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pss|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )

    over_pss_threshold = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '<text '
        '{% if record.over_pss_threshold != "" %}'
        'class="color_parent_td red"'
        '{% endif %}'
        '>'
        '{{ record.over_pss_threshold|binary_suffix }}'
        '</text>',
        verbose_name="Over Threshold",
        attrs={'td': {'class': 'num'}},
    )

    uss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.uss|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )

    rss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.rss|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )

    swap = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.swap|binary_suffix }}',
        attrs={'td': {'class': 'num'}},
    )


class ArchOverviewTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventImage
        fields = (
            'build_number',
            'release',
            'variant',
            'status',
        )
        order_by = (
            'variant',
            '-rootfs_id',
            '-build_id',
            '-device_specific_id',
            '-customization_id',
            '-build_number',
        )

    build_number = tables.TemplateColumn(
        '<a href='
        '"{% url "memevent_image_overview" record.id record.machine %}">'
        '{{ record.build_number }}</a>',
    )
    status = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '<text '
        '{% if record.failed %}'
        'class="color_parent_td red"'
        '{% else %}'
        'class="color_parent_td green"'
        '{% endif %}'
        '>'
        '{{ record.status }}'
        '</text>',
    )
    threshold = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '<text {% if record.threshold != "" %}'
        'class="color_parent_td red"{% endif %}>'
        '{{ record.threshold }}'
        '</text>',
        verbose_name="Over Threshold",
        attrs={'td': {'class': 'num'}},
    )


class ImageOverviewTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventImage
        fields = (
            'event',
            'average',
        )
        order_by = ('average',)

    average = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.average|binary_suffix }}',
        verbose_name="PSS Average",
        attrs={'td': {'class': 'num'}},
    )
    event = tables.TemplateColumn(
        '<a href="{% url "memevent_event_detail" record.id record.machine '
        'record.event %}">'
        '{{ record.event }}</a>'
    )
