# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

import datetime

from django.test import TestCase

from common.models import (
    JenkinsJob,
    JenkinsBuild,
)

from memevent.models import (
    MemoryEventDetail,
    MemoryEventImage,
    MemoryEventMachine,
)


class TestMemoryEvent(TestCase):
    """ Test MemoryEvent models. """

    def setUp(self):
        """ Common setup. """

        self.jenkins_job = JenkinsJob.objects.create(
            name="jenkins_job",
            url="http://somewhere.com",
        )

        self.assert_(self.jenkins_job)

        self.jenkins_build = JenkinsBuild.objects.create(
            job=self.jenkins_job,
            url="http://somewhere.com",
            ran_at=datetime.datetime.now(),
            build_number='10',
        )

        self.assert_(self.jenkins_build)

        self.image = MemoryEventImage.objects.create(
            arch="armhf",
            release="saucy",
            variant="touch",
            build_number="20130701",
        )

        self.assert_(self.image)

        self.machine = MemoryEventMachine.objects.create(
            name="maguro",
            mac_address="fake",
        )

        self.assert_(self.machine)

        self.detail = MemoryEventDetail.objects.create(
            image=self.image,
            machine=self.machine,
            command="bash",
            pid=10,
            pss=100,
            rss=200,
            uss=300,
            swap=0,
            user="root",
            ran_at=datetime.datetime.now(),
            event="event",
            event_index=1,
            run=1,
            jenkins_build=self.jenkins_build,
        )

        self.assert_(self.detail)

    def test_simple(self):
        self.assert_(self.detail)
