# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging
import os
import sys
import subprocess

sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'qa_dashboard.settings'

from django.core.management import call_command

from common.utils import (
    lockfile_dec,
    txstatsd_interval,
)

script_dir = os.path.dirname(os.path.realpath(__file__))
basedir = os.path.realpath(os.path.join(script_dir, ".."))
project = os.path.basename(basedir)
fast_lock_file = '/var/lock/update-fast-{}.lock'.format(project)
slow_lock_file = '/var/lock/update-slow-{}.lock'.format(project)
code_lock_file = '/var/lock/update-code-{}.lock'.format(project)


@lockfile_dec(code_lock_file)
@lockfile_dec(slow_lock_file, wait=True)
@lockfile_dec(fast_lock_file, wait=True)
@txstatsd_interval('branch_update')
def branch_update():

    new_version = False

    with open(os.devnull, 'w') as FNULL:
        if subprocess.call(['bzr', 'missing'], stdout=FNULL, cwd=script_dir):
            new_version = True

    if new_version:
        subprocess.check_call(['bzr', 'pull'], cwd=script_dir)
        call_command('syncdb')
        call_command('migrate')
        call_command('collectstatic', interactive=False)

        subprocess.check_call(
            ['sudo', 'service', 'apache2', 'graceful'],
            cwd=script_dir,
        )

    call_command('plugin_sync')

if __name__ == "__main__":
    try:
        branch_update()
    except Exception as e:
        logging.error(e)
