#!/bin/python

# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import argparse
import logging
import os
import sys

sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'qa_dashboard.settings'

from django.core.management import call_command

from common.utils import (
    lockfile_dec,
    txstatsd_interval,
    DEFAULT_DAYS,
)

script_dir = os.path.dirname(os.path.realpath(__file__))
basedir = os.path.realpath(os.path.join(script_dir, ".."))
project = os.path.basename(basedir)
fast_lock_file = '/var/lock/update-fast-{}.lock'.format(project)
slow_lock_file = '/var/lock/update-slow-{}.lock'.format(project)
logger = logging.getLogger("update_pull")


@lockfile_dec(slow_lock_file)
@txstatsd_interval('update_slow', append_days=True)
def update_slow(days):

    update_sru(days=days)
    update_bootspeed(days=days)
    update_power(days=days)
    update_memory(days=days)
    #update_idlepower(days=days)
    update_eventstat(days=days)
    update_plugin_data(days=days)


@lockfile_dec(fast_lock_file)
@txstatsd_interval('update_fast', append_days=True)
def update_fast(days=DEFAULT_DAYS):

    update_smokeng(days=days)
    update_lp_bugs()


@txstatsd_interval('jenkins_pull_smokeng', append_days=True)
def update_smokeng(days=DEFAULT_DAYS):
    call_command('jenkins_pull_smokeng', days=days)


@txstatsd_interval('launchpad_pull_bugs')
def update_lp_bugs():
    call_command('launchpad_pull_bugs')


@txstatsd_interval('jenkins_pull_sru', append_days=True)
def update_sru(days=DEFAULT_DAYS):
    call_command('jenkins_pull_sru', days=DEFAULT_DAYS)


@txstatsd_interval('jenkins_pull_bootspeed', append_days=True)
def update_bootspeed(days=DEFAULT_DAYS):
    call_command('jenkins_pull_bootspeed', days=DEFAULT_DAYS)


@txstatsd_interval('jenkins_pull_power', append_days=True)
def update_power(days=DEFAULT_DAYS):
    call_command('jenkins_pull_power', days=DEFAULT_DAYS)


@txstatsd_interval('jenkins_pull_idlepower', append_days=True)
def update_idlepower(days=DEFAULT_DAYS):
    call_command('jenkins_pull_idlepower', days=DEFAULT_DAYS)


@txstatsd_interval('jenkins_pull_memory', append_days=True)
def update_memory(days=DEFAULT_DAYS):
    call_command('jenkins_pull_memory', days=DEFAULT_DAYS)


@txstatsd_interval('jenkins_pull_eventstat', append_days=True)
def update_eventstat(days=DEFAULT_DAYS):
    call_command('jenkins_pull_eventstat', days=DEFAULT_DAYS)


@txstatsd_interval('pull_plugin_data')
def update_plugin_data(days=DEFAULT_DAYS):
    call_command('pull_plugin_data')

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='CI Dashboard update script')
    parser.add_argument(
        '-f', '--fast',
        dest='run_fast',
        default=False,
        action="store_true",
        help="Whether to run the fast or slow version.  I.e. different data is"
        " pulled for short interval runs and long interval runs"
    )
    parser.add_argument(
        '-v', '--verbose',
        dest='verbose',
        default=0,
        type=int,
        help="More verbose output"
    )
    parser.add_argument(
        '-d', '--days',
        dest='days',
        default=DEFAULT_DAYS,
        help="Number of days worth of data to process."
    )

    args = parser.parse_args()

    days = args.days
    run_fast = args.run_fast
    verbose = args.verbose

    if verbose >= 2:
        logger.setLevel(level=logging.DEBUG)
        logging.getLogger().setLevel(level=logging.DEBUG)
    elif verbose == 1:
        logger.setLevel(level=logging.INFO)
        logging.getLogger().setLevel(level=logging.INFO)

    if run_fast:
        update_fast(days=days)
    else:
        update_slow(days=days)
