# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from smokeng.models import (
    SmokeImage,
    SmokeResult,
    SmokeResultBug,
    SmokeTestResult,
)

from django.contrib import admin


class SmokeImageAdmin(admin.ModelAdmin):
    list_filter = ['publish', 'release', 'variant', 'arch']
    search_fields = [
        'build_number',
    ]
    list_display = ('build_number', 'variant', 'arch', 'release', 'publish')
    ordering = ['-build_number']


class SmokeResultAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'name',
        'status',
        'fail_count',
        'error_count',
        'pass_count',
        'total_count',
        'ran_at',
        'publish',
    )
    list_filter = ['publish', 'status', 'name']
    search_fields = ['name']
    date_hierarchy = 'ran_at'
    ordering = ['image']


class SmokeResultBugAdmin(admin.ModelAdmin):
    list_display = ('bug', 'result')
    list_filter = ['bug']
    search_fields = ['bug']
    ordering = ['-bug']


class SmokeTestResultAdmin(admin.ModelAdmin):
    list_display = ('result', 'testcase', 'returncode')
    ordering = ['result']

admin.site.register(SmokeImage, SmokeImageAdmin)
admin.site.register(SmokeResult, SmokeResultAdmin)
admin.site.register(SmokeResultBug, SmokeResultBugAdmin)
admin.site.register(SmokeTestResult, SmokeTestResultAdmin)
