# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sru.models import (
    Kernel,
    SRUResult,
)

from django.contrib import admin


class KernelAdmin(admin.ModelAdmin):
    list_display = (
        'version',
        'job_type',
        'release',
        'variant',
        'arch',
        'gpu',
    )

    list_filter = [
        'job_type',
        'release',
        'variant',
        'arch',
        'gpu',
        'version',
    ]

    search_fields = ['job_type']
    ordering = ['-version']


class SRUResultAdmin(admin.ModelAdmin):
    list_display = (
        'kernel',
        'pass_count',
        'fail_count',
        'skip_count',
        'total_count',
        'ran_at',
        'publish',
    )

    list_filter = [
        'kernel',
    ]

    date_hierarchy = 'ran_at'
    ordering = ['-ran_at']

admin.site.register(Kernel, KernelAdmin)
admin.site.register(SRUResult, SRUResultAdmin)
