# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django_tables2 as tables
from django_tables2.utils import Accessor as A


class SRUBaseTable(tables.Table):
    class Meta:
        attrs = {'class': 'basic wide'}
        fields = (
            'total_count',
            'pass_count',
            'fail_count',
            'pass_rate',
            'bug_count',
        )

    total_count = tables.Column(
        verbose_name="Total",
        attrs={'td': {'class': 'num'}},
    )
    pass_count = tables.Column(
        verbose_name="Pass",
        attrs={'td': {'class': 'num'}},
    )
    fail_count = tables.Column(
        verbose_name="Fail",
        attrs={'td': {'class': 'num'}},
    )
    pass_rate = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pass_rate|decimal_to_percent }}',
        attrs={'td': {'class': 'num pass_rate_color'}},
    )
    td_class_extra = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pass_rate|pass_rate_color }}',
        visible=False,
    )
    bug_count = tables.Column(
        verbose_name="Bugs",
        attrs={'td': {'class': 'num'}},
    )


class SRUKernelTable(SRUBaseTable):
    version = tables.LinkColumn(
        'sru.views.overview_kernel',
        args={
            A('release'),
            A('version'),
        },
        verbose_name="Kernel",
    )
    last_run_date = tables.TemplateColumn('{{ record.last_run_date }}')

    class Meta(SRUBaseTable.Meta):
        order_by = ('-version',)
        fields = (
            'version',
            'last_run_date',
        ) + SRUBaseTable.Meta.fields


class SRUFlatKernelTable(SRUKernelTable):
    arch = tables.TemplateColumn(
        '{{ record.arch }}',
        verbose_name="arch",
    )
    release = tables.Column()

    class Meta(SRUBaseTable.Meta):
        order_by = ('-version',)
        fields = (
            'version',
            'release',
            'arch',
            'last_run_date',
        ) + SRUBaseTable.Meta.fields


class SRUResultTable(SRUBaseTable):
    class Meta(SRUBaseTable.Meta):
        order_by = ('-ran_at', 'variant',)
        fields = (
            'variant',
            'arch',
            'gpu',
            'ran_at',
        ) + SRUBaseTable.Meta.fields

    ran_at = tables.Column(
        verbose_name="date",
    )
    arch = tables.Column(
        verbose_name="arch",
    )
    variant = tables.TemplateColumn(
        '<a href="{{ record.jenkins_url }}">{{ record.variant }}</a>',
    )
    gpu = tables.Column(
        verbose_name="graphics",
    )
