# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.test import TestCase
from django.core.urlresolvers import reverse
from django.test.client import Client

from sru.models import Kernel


class TestSruUrls(TestCase):
    """ Tests for sru app urls. """

    c = Client()

    def setUp(self):
        """ Setup commonly used objects. """

        self.kernel = Kernel.objects.create(
            job_type='sru_kernel',
            release='raring',
            variant='virtual_i386_pae',
            arch='kvm',
            gpu='virtual',
            version='3.8.0-19.30-generic',
        )

    def _test_url(self, url):
        response = self.c.get(url)

        self.assertEqual(response.status_code, 200)

    def test_sru_index_url(self):
        response = self.c.get(
            reverse(
                'sru_index',
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_index_flat_url(self):
        response = self.c.get(
            reverse(
                'sru_index',
                args=('flat', ),
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_index_all_url(self):
        response = self.c.get(
            reverse(
                'sru_index',
                args=('all', ),
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_index_flat_all_url(self):
        response = self.c.get(
            reverse(
                'sru_index',
                args=('flat', 'all'),
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_overview_url(self):
        args = [self.kernel.release, ]
        response = self.c.get(
            reverse(
                'sru_overview',
                args=args,
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_overview_flat_url(self):
        args = [self.kernel.release, 'flat']
        response = self.c.get(
            reverse(
                'sru_overview',
                args=args,
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_overview_all_url(self):
        args = [self.kernel.release, 'all']
        response = self.c.get(
            reverse(
                'sru_overview',
                args=args,
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_overview_flat_all_url(self):
        args = [self.kernel.release, 'flat', 'all']
        response = self.c.get(
            reverse(
                'sru_overview',
                args=args,
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview.html')

    def test_sru_overview_kernel_url(self):
        args = [self.kernel.release, self.kernel.version]
        response = self.c.get(
            reverse(
                'sru_overview_kernel',
                args=args,
            ),
        )
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'sru/overview_kernel.html')

    def test_overview_kernel_pass_rate_sorting(self):
        args = [self.kernel.release, self.kernel.version]
        url = reverse(
            'sru_overview_kernel',
            args=args,
        )

        self._test_url("{}?sort=pass_rate".format(url))

    def test_overview_kernel_bug_count_sorting(self):
        args = [self.kernel.release, self.kernel.version]
        url = reverse(
            'sru_overview_kernel',
            args=args,
        )

        self._test_url("{}?sort=bug_count".format(url))

    def test_index_pass_rate_sorting(self):
        url = reverse(
            'sru_index',
        )

        self._test_url("{}?sort=pass_rate".format(url))

    def test_index_bug_count_sorting(self):
        url = reverse(
            'sru_index',
        )

        self._test_url("{}?sort=bug_count".format(url))
